@@ -923,9 +923,9 @@ pub fn impl_widget_trait(ast: &DeriveInput) -> TokenStream {
             fn set_image<I: ImageExt>(&mut self, image: Option<I>) {
                 assert!(!self.was_deleted());
                 let _old_image = self.image();
-                if let Some(mut image) = image {
+                if let Some(image) = image {
                     assert!(!image.was_deleted());
-                    unsafe { image.increment_arc(); #set_image(self.inner, image.as_image_ptr() as *mut _) }
+                    unsafe { #set_image(self.inner, image.as_image_ptr() as *mut _) }
                 } else {
                     unsafe { #set_image(self.inner, std::ptr::null_mut() as *mut raw::c_void) }
                 }
@@ -938,17 +938,18 @@ pub fn impl_widget_trait(ast: &DeriveInput) -> TokenStream {
                     if image_ptr.is_null() {
                         None
                     } else {
-                        Some(Box::new(Image::from_image_ptr(image_ptr as *mut fltk_sys::image::Fl_Image)))
+                        let mut img = Image::from_image_ptr(image_ptr as *mut fltk_sys::image::Fl_Image);
+                        Some(Box::new(img))
                     }
                 }
             }
 
             fn set_deimage<I: ImageExt>(&mut self, image: Option<I>) {
                 assert!(!self.was_deleted());
-                let _old_image = self.image();
-                if let Some(mut image) = image {
+                let _old_image = self.deimage();
+                if let Some(image) = image {
                     assert!(!image.was_deleted());
-                    unsafe { image.increment_arc(); #set_deimage(self.inner, image.as_image_ptr() as *mut _) }
+                    unsafe { #set_deimage(self.inner, image.as_image_ptr() as *mut _) }
                 } else {
                     unsafe { #set_deimage(self.inner, std::ptr::null_mut() as *mut raw::c_void) }
                 }
@@ -961,7 +962,8 @@ pub fn impl_widget_trait(ast: &DeriveInput) -> TokenStream {
                     if image_ptr.is_null() {
                         None
                     } else {
-                        Some(Box::new(Image::from_image_ptr(image_ptr as *mut fltk_sys::image::Fl_Image)))
+                        let mut img = Image::from_image_ptr(image_ptr as *mut fltk_sys::image::Fl_Image);
+                        Some(Box::new(img))
                     }
                 }
             }
